@@ -144,12 +144,18 @@ class BaseClient:
         return _headers
 
     @staticmethod
-    def _add_to_cache(cache: dict, subject: str, schema: AvroSchema, value: typing.Union[str, int]) -> None:
+    def _add_to_cache(
+        cache: dict, subject: str, schema: typing.Union[AvroSchema, str], value: typing.Union[str, int]
+    ) -> None:
         sub_cache = cache[subject]
         sub_cache[schema] = value
 
     def _cache_schema(
-        self, schema: AvroSchema, schema_id: int, subject: str = None, version: typing.Union[str, int] = None
+        self,
+        schema: typing.Union[AvroSchema, str],
+        schema_id: int,
+        subject: str = None,
+        version: typing.Union[str, int] = None,
     ) -> None:
         if schema_id in self.id_to_schema:
             schema = self.id_to_schema[schema_id]
@@ -220,7 +226,7 @@ class SchemaRegistryClient(BaseClient):
     def register(
         self,
         subject: str,
-        avro_schema: AvroSchema,
+        avro_schema: typing.Union[AvroSchema, str],
         headers: dict = None,
         timeout: typing.Union[TimeoutTypes, UnsetType] = UNSET,
     ) -> int:
@@ -233,7 +239,7 @@ class SchemaRegistryClient(BaseClient):
 
         Args:
             subject (str): subject name
-            avro_schema (avro.schema.RecordSchema): Avro schema to be registered
+            avro_schema typing.Union[avro.schema.AvroSchema, str]: Avro schema to be registered
             headers (dict): Extra headers to add on the requests
             timeout (httpx._client.TimeoutTypes): The timeout configuration to use when sending requests. Default UNSET
 
@@ -241,6 +247,10 @@ class SchemaRegistryClient(BaseClient):
             int: schema_id
         """
         schemas_to_id = self.subject_to_schema_ids[subject]
+
+        if isinstance(avro_schema, str):
+            avro_schema = AvroSchema(avro_schema)
+
         schema_id = schemas_to_id.get(avro_schema)
 
         if schema_id is not None:
@@ -467,7 +477,7 @@ class SchemaRegistryClient(BaseClient):
     def check_version(
         self,
         subject: str,
-        avro_schema: AvroSchema,
+        avro_schema: typing.Union[AvroSchema, str],
         headers: dict = None,
         timeout: typing.Union[TimeoutTypes, UnsetType] = UNSET,
     ) -> typing.Optional[utils.SchemaVersion]:
@@ -479,7 +489,7 @@ class SchemaRegistryClient(BaseClient):
 
         Args:
             subject (str): subject name
-            avro_schema (avro.schema.RecordSchema): Avro schema
+            avro_schema typing.Union[avro.schema.AvroSchema, str]: Avro schema
             headers (dict): Extra headers to add on the requests
             timeout (httpx._client.TimeoutTypes): The timeout configuration to use when sending requests. Default UNSET
 
@@ -488,6 +498,10 @@ class SchemaRegistryClient(BaseClient):
             None: If schema not found.
         """
         schemas_to_version = self.subject_to_schema_versions[subject]
+
+        if isinstance(avro_schema, str):
+            avro_schema = AvroSchema(avro_schema)
+
         version = schemas_to_version.get(avro_schema)
 
         schemas_to_id = self.subject_to_schema_ids[subject]
@@ -515,7 +529,7 @@ class SchemaRegistryClient(BaseClient):
     def test_compatibility(
         self,
         subject: str,
-        avro_schema: AvroSchema,
+        avro_schema: typing.Union[AvroSchema, str],
         version: typing.Union[int, str] = "latest",
         headers: dict = None,
         timeout: typing.Union[TimeoutTypes, UnsetType] = UNSET,
@@ -527,7 +541,7 @@ class SchemaRegistryClient(BaseClient):
 
         Args:
             subject (str): subject name
-            avro_schema (avro.schema.RecordSchema): Avro schema
+            avro_schema typing.Union[avro.schema.AvroSchema, str]: Avro schema
             headers (dict): Extra headers to add on the requests
             timeout (httpx._client.TimeoutTypes): The timeout configuration to use when sending requests. Default UNSET
 
@@ -535,6 +549,10 @@ class SchemaRegistryClient(BaseClient):
             bool: True if schema given compatible, False otherwise
         """
         url, method = self.url_manager.url_for("test_compatibility", subject=subject, version=version)
+
+        if isinstance(avro_schema, str):
+            avro_schema = AvroSchema(avro_schema)
+
         body = {"schema": json.dumps(avro_schema.raw_schema)}
         result, code = self.request(url, method=method, body=body, headers=headers, timeout=timeout)
 
@@ -681,7 +699,7 @@ class AsyncSchemaRegistryClient(BaseClient):
     async def register(
         self,
         subject: str,
-        avro_schema: AvroSchema,
+        avro_schema: typing.Union[AvroSchema, str],
         headers: dict = None,
         timeout: typing.Union[TimeoutTypes, UnsetType] = UNSET,
     ) -> int:
@@ -694,7 +712,7 @@ class AsyncSchemaRegistryClient(BaseClient):
 
         Args:
             subject (str): subject name
-            avro_schema (avro.schema.RecordSchema): Avro schema to be registered
+            avro_schema typing.Union[avro.schema.AvroSchema, str]: Avro schema
             headers (dict): Extra headers to add on the requests
             timeout (httpx._client.TimeoutTypes): The timeout configuration to use when sending requests. Default UNSET
 
@@ -702,6 +720,10 @@ class AsyncSchemaRegistryClient(BaseClient):
             int: schema_id
         """
         schemas_to_id = self.subject_to_schema_ids[subject]
+
+        if isinstance(avro_schema, str):
+            avro_schema = AvroSchema(avro_schema)
+
         schema_id = schemas_to_id.get(avro_schema)
 
         if schema_id is not None:
@@ -928,7 +950,7 @@ class AsyncSchemaRegistryClient(BaseClient):
     async def check_version(
         self,
         subject: str,
-        avro_schema: AvroSchema,
+        avro_schema: typing.Union[AvroSchema, str],
         headers: dict = None,
         timeout: typing.Union[TimeoutTypes, UnsetType] = UNSET,
     ) -> typing.Optional[utils.SchemaVersion]:
@@ -940,7 +962,7 @@ class AsyncSchemaRegistryClient(BaseClient):
 
         Args:
             subject (str): subject name
-            avro_schema (avro.schema.RecordSchema): Avro schema
+            avro_schema typing.Union[avro.schema.AvroSchema, str]: Avro schema
             headers (dict): Extra headers to add on the requests
             timeout (httpx._client.TimeoutTypes): The timeout configuration to use when sending requests. Default UNSET
 
@@ -949,6 +971,10 @@ class AsyncSchemaRegistryClient(BaseClient):
             None: If schema not found.
         """
         schemas_to_version = self.subject_to_schema_versions[subject]
+
+        if isinstance(avro_schema, str):
+            avro_schema = AvroSchema(avro_schema)
+
         version = schemas_to_version.get(avro_schema)
 
         schemas_to_id = self.subject_to_schema_ids[subject]
@@ -958,7 +984,7 @@ class AsyncSchemaRegistryClient(BaseClient):
             return utils.SchemaVersion(subject, schema_id, version, avro_schema)
 
         url, method = self.url_manager.url_for("check_version", subject=subject)
-        body = {"schema": json.dumps(avro_schema.raw_schema)}
+        body = {"schema": json.dumps(avro_schema.raw_schema) if isinstance(avro_schema, AvroSchema) else avro_schema}
 
         result, code = await self.request(url, method=method, body=body, headers=headers, timeout=timeout)
         if code == status.HTTP_404_NOT_FOUND:
@@ -976,7 +1002,7 @@ class AsyncSchemaRegistryClient(BaseClient):
     async def test_compatibility(
         self,
         subject: str,
-        avro_schema: AvroSchema,
+        avro_schema: typing.Union[AvroSchema, str],
         version: typing.Union[int, str] = "latest",
         headers: dict = None,
         timeout: typing.Union[TimeoutTypes, UnsetType] = UNSET,
@@ -988,7 +1014,7 @@ class AsyncSchemaRegistryClient(BaseClient):
 
         Args:
             subject (str): subject name
-            avro_schema (avro.schema.RecordSchema): Avro schema
+            avro_schema typing.Union[avro.schema.AvroSchema, str]: Avro schema
             headers (dict): Extra headers to add on the requests
             timeout (httpx._client.TimeoutTypes): The timeout configuration to use when sending requests. Default UNSET
 
@@ -996,6 +1022,10 @@ class AsyncSchemaRegistryClient(BaseClient):
             bool: True if schema given compatible, False otherwise
         """
         url, method = self.url_manager.url_for("test_compatibility", subject=subject, version=version)
+
+        if isinstance(avro_schema, str):
+            avro_schema = AvroSchema(avro_schema)
+
         body = {"schema": json.dumps(avro_schema.raw_schema)}
         result, code = await self.request(url, method=method, body=body, headers=headers, timeout=timeout)
 
